package ValidateSubApp;

use strict;
use CGI::Application;
use base qw/ValidateApp/;

sub valid_html {
	return q{<?xml version="1.0"?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN"
    "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">

<html xmlns="http://www.w3.org/1999/xhtml">
<head>
      <title>Valid output</title>
</head>
<body>
	This is okay
</body>
</html>

	};
}

1;

